##  Additional Obsolescence Risk Management Views in Reports
The following additional obsolescence risk management views are added to reports, helping you better analyze and prioritize technological risks:
  * Mitigated Risk: Helps organizations to assess how effectively they've addressed and reduced risks.
  * Missing Data: Helps identify gaps in available information critical for risk evaluation, enabling focused data completion efforts.
  * Unaddressed Risk Percentages: Helps prioritize and tackle risks that still require attention.


For a more detailed guide, see [Technology Obsolescence Risk Statuses and Views in Reports](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how risk statuses are determined for IT components and applications and understand reporting views, such as Missing Data Percentage, Mitigated Risk Percentage, and Unaddressed Risk Percentage.").
![Unaddressed Risk Percentage View in a Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757f8ef7a441014a575b96f318a2e29_LowRes.png)
Unaddressed Risk Percentage View in a Report
